==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/pt_BR.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Documentos",
    "Can't create document" : "Impedido de criar documentos",
    "You don't have permission to rename this document" : "Você não tem permissão para renomear este documento",
    "Directory saved successfully." : "Diretório salvo com sucesso.",
    "An error occurred while changing directory." : "Ocorreu um erro ao mudar de diretório.",
    "Saved" : "Salvo",
    "Format filter server is down or misconfigured" : "O servidor de formato de filtro está desligado ou com configuração errada",
    "Conversion failed. Check log for details." : "Falha na conversão. Verifique o log para detalhes.",
    "document-styles" : "estilo-de-documentos",
    "document-content" : "conteúdo-de-documentos",
    "bold" : "negrito",
    "italic" : "itálico",
    "solid" : "sólido",
    "pt" : "pt",
    "Saving..." : "Salvando...",
    "Failed to load documents." : "Falha ao carregar documentos.",
    "No documents were found. Upload or create a document to get started!" : "Nenhum documento foi encontrado. Enviar ou criar um documento para iniciar.",
    "No connection to server. Trying to reconnect." : "Sem conexão com o servidor. Tentando reconectar.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Deixando esta página no modo de Edição pode causar o não salvamento de dados. É recomendado usar o botão \"Fechar\".",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Falha ao carregar o documento. Por favor verifique se o arquivo poderá ser aberto com um editor externo odt. Isso também pode significar que o arquivo foi descompartilhado ou eliminado recentemente.",
    "Save" : "Salvar",
    "Loading documents..." : "Carregando documentos...",
    "'.' is an invalid file name." : "'.' é um nome de arquivo inválido.",
    "File name cannot be empty." : "O nome do arquivo não pode estar vazio.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Nome inválido, '\\', '/', '<', '>', ':', '\"', '|', '?' e '*' não são permitidos.",
    "Align Left" : "Alinhar a esquerda",
    "Alignment" : "Alinhamento",
    "Align Right" : "Alinhar a direita",
    "Annotate" : "Anotar",
    "Background" : "Fundo",
    "Bold" : "Negrito",
    "Bottom" : "Pé",
    "Cancel" : "Cancelar",
    "Center" : "Centro",
    "Clone" : "Clone",
    "Clone this Style" : "Clonar este estilo",
    "Close" : "Fechar",
    "Color" : "Cor",
    "Create" : "Criar",
    "Decrease Indent" : "Diminuir recuo",
    "Default Style" : "Estilo Padrão",
    "Delete" : "Eliminar",
    "Family" : "Família",
    "Font" : "Fonte",
    "Font Effects" : "Fonte Efeitos",
    "Format" : "Formato",
    "Increase Indent" : "Aumentar recuo",
    "Insert Image" : "Inserir Imagem",
    "Invite Members" : "Convidar Membros",
    "Italic" : "Itálico",
    "Justified" : "Justificado",
    "Justify" : "Justificar",
    "Left" : "Esquerda",
    "Loading" : "Carregando",
    "Members" : "Membros",
    "New Name:" : "Novo Nome:",
    "OK" : "OK",
    "Open" : "Abrir",
    "Options" : "Opções",
    "Paragraph..." : "Parágrafo...",
    "Paragraph Styles" : "Estilo de Parágrafo",
    "Redo" : "Refazer",
    "Right" : "Direita",
    "Size" : "Tamanho",
    "Spacing" : "Espaçamento",
    "Strikethrough" : "Rasurado",
    "Style" : "Estilo",
    "Text" : "Texto",
    "Top" : "Topo",
    "Underline" : "Sublinhado",
    "Undo" : "Desfazer",
    "Unknown Author" : "Autor Desconhecido",
    "Edit" : "Editar",
    "Share" : "Compartilhar",
    "guest" : "convidado",
    "MS Word support (requires openOffice/libreOffice)" : "Suporte  a MS Word (requer openOdffice/libreOffice)",
    "Local" : "Local",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice está instalado no servidor. O caminho para o binário é disponibilizado via preview_libreoffice_path no config.php",
    "External" : "Externo",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice está instalado em um servidor externo executando um servidor de filtro de formato",
    "Disabled" : "Desabilitado",
    "No MS Word support" : "Sem suporte para o MS Word",
    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
    "Server URL" : "URL do servidor",
    "Apply and test" : "Aplicar e testar",
    "New document" : "Novo documento",
    "Upload (max. %s)" : "Envio (max. %s)",
    "Upload" : "Enviar",
    "Save new documents to" : "Salvar o novo documento para",
    "Wrong password. Please retry." : "Senha errada. Por favor tente novamente.",
    "Password" : "Senha",
    "Guest %s" : "Convidado %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Este link expirou ou nunca existiu. Por favor faça contato com a pessoa que compartilhou este link com você para maiores detalhes.",
    "Advanced feature-set" : "Avançado conjunto de funcionalidades",
    "(Unstable)" : "(Instável)"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-app-documents-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/pt_BR.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Documentos",
    "Can't create document" : "Impedido de criar documentos",
    "You don't have permission to rename this document" : "Você não tem permissão para renomear este documento",
    "File does not exist" : "O arquivo não existe",
    "Directory saved successfully." : "Diretório salvo com sucesso.",
    "An error occurred while changing directory." : "Ocorreu um erro ao mudar de diretório.",
    "Saved" : "Salvo",
    "Format filter server is down or misconfigured" : "O servidor de formato de filtro está desligado ou com configuração errada",
    "Conversion failed. Check log for details." : "Falha na conversão. Verifique o log para detalhes.",
    "Saving..." : "Salvando...",
    "Failed to load documents." : "Falha ao carregar documentos.",
    "No documents were found. Upload or create a document to get started!" : "Nenhum documento foi encontrado. Enviar ou criar um documento para iniciar.",
    "No connection to server. Trying to reconnect." : "Sem conexão com o servidor. Tentando reconectar.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Deixando esta página no modo de Edição pode causar o não salvamento de dados. É recomendado usar o botão \"Fechar\".",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Falha ao carregar o documento. Por favor verifique se o arquivo poderá ser aberto com um editor externo odt. Isso também pode significar que o arquivo foi descompartilhado ou eliminado recentemente.",
    "Save" : "Salvar",
    "Loading documents..." : "Carregando documentos...",
    "'.' is an invalid file name." : "'.' é um nome de arquivo inválido.",
    "File name cannot be empty." : "O nome do arquivo não pode estar vazio.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Nome inválido, '\\', '/', '<', '>', ':', '\"', '|', '?' e '*' não são permitidos.",
    "Align Left" : "Alinhar a esquerda",
    "Alignment" : "Alinhamento",
    "Align Right" : "Alinhar a direita",
    "Annotate" : "Anotar",
    "Background" : "Fundo",
    "Bold" : "Negrito",
    "Bottom" : "Pé",
    "Cancel" : "Cancelar",
    "Center" : "Centro",
    "Clone" : "Clone",
    "Clone this Style" : "Clonar este estilo",
    "Close" : "Fechar",
    "Color" : "Cor",
    "Create" : "Criar",
    "Decrease Indent" : "Diminuir recuo",
    "Default Style" : "Estilo Padrão",
    "Delete" : "Eliminar",
    "Family" : "Família",
    "Font" : "Fonte",
    "Font Effects" : "Efeitos da Fonte",
    "Format" : "Formato",
    "Increase Indent" : "Aumentar recuo",
    "Insert Image" : "Inserir Imagem",
    "Invite Members" : "Convidar Membros",
    "Italic" : "Itálico",
    "Justified" : "Justificado",
    "Justify" : "Justificar",
    "Left" : "Esquerda",
    "Loading" : "Carregando",
    "Members" : "Membros",
    "New Name:" : "Novo Nome:",
    "OK" : "OK",
    "Open" : "Abrir",
    "Options" : "Opções",
    "Paragraph..." : "Parágrafo...",
    "Paragraph Styles" : "Estilo de Parágrafo",
    "Redo" : "Refazer",
    "Right" : "Direita",
    "Size" : "Tamanho",
    "Spacing" : "Espaçamento",
    "Strikethrough" : "Rasurado",
    "Style" : "Estilo",
    "Text" : "Texto",
    "Top" : "Topo",
    "Underline" : "Sublinhado",
    "Undo" : "Desfazer",
    "Unknown Author" : "Autor Desconhecido",
    "Shared" : "Compartilhado",
    "Error" : "Erro",
    "Error while sharing" : "Erro ao compartilhar",
    "Error while unsharing" : "Erro ao descompartilhar",
    "Error while changing permissions" : "Erro ao mudar permissões",
    "Shared with you and the group {group} by {owner}" : "Compartilhado com você e com o grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartilhado com você por {owner}",
    "Share with users or groups …" : "Compartilhar com usuários ou grupos ...",
    "Share with users, groups or remote users …" : "Compartilhar com usuários, grupos ou usuários remoto ...",
    "Share" : "Compartilhar",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Compartilhar com usuários em outros ownClouds usando a sintaxe username@example.com/owncloud",
    "Share link" : "Compartilhar link",
    "The public link will expire no later than {days} days after it is created" : "O link público irá expirar não antes de {days} depois de ser criado",
    "Link" : "Link",
    "Password protect" : "Proteger com senha",
    "Password" : "Senha",
    "Choose a password for the public link" : "Escolha uma senha para o link público",
    "Allow editing" : "Permitir edição",
    "Email link to person" : "Enviar link por e-mail",
    "Send" : "Enviar",
    "Set expiration date" : "Definir data de expiração",
    "Expiration" : "Expiração",
    "Expiration date" : "Data de expiração",
    "An error occured. Please try again" : "Ocorreu um erro. Por favor tente novamente",
    "Adding user..." : "Adicionando usuário...",
    "group" : "grupo",
    "remote" : "remoto",
    "Resharing is not allowed" : "Não é permitido re-compartilhar",
    "Shared in {item} with {user}" : "Compartilhado em {item} com {user}",
    "Unshare" : "Descompartilhar",
    "notify by email" : "notificar por e-mail",
    "can share" : "pode compartilhar",
    "can edit" : "pode editar",
    "access control" : "controle de acesso",
    "create" : "criar",
    "change" : "mudança",
    "delete" : "excluir",
    "Password protected" : "Protegido com senha",
    "Error unsetting expiration date" : "Erro ao remover data de expiração",
    "Error setting expiration date" : "Erro ao definir data de expiração",
    "Sending ..." : "Enviando ...",
    "Email sent" : "E-mail enviado",
    "Warning" : "Aviso",
    "Edit" : "Editar",
    "guest" : "convidado",
    "MS Word support (requires openOffice/libreOffice)" : "Suporte  a MS Word (requer openOdffice/libreOffice)",
    "Local" : "Local",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice está instalado no servidor. O caminho para o binário é disponibilizado via preview_libreoffice_path no config.php",
    "External" : "Externo",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice está instalado em um servidor externo executando um servidor de filtro de formato",
    "Disabled" : "Desabilitado",
    "No MS Word support" : "Sem suporte para o MS Word",
    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
    "Server URL" : "URL do servidor",
    "Apply and test" : "Aplicar e testar",
    "New document" : "Novo documento",
    "Upload (max. %s)" : "Envio (max. %s)",
    "Upload" : "Enviar",
    "Save new documents to" : "Salvar o novo documento para",
    "Wrong password. Please retry." : "Senha errada. Por favor tente novamente.",
    "Guest %s" : "Convidado %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Este link expirou ou nunca existiu. Por favor faça contato com a pessoa que compartilhou este link com você para maiores detalhes.",
    "Advanced feature-set" : "Avançado conjunto de funcionalidades",
    "(Unstable)" : "(Instável)"
},
"nplurals=2; plural=(n > 1);");
